%define fver		%{version}
%define libmajor	1.10
%define apiversion	1.10
%define pkgname		openshadinglanguage

%define libname		%mklibname %{pkgname} %{apiversion} %{libmajor}
%define develname	%mklibname -d %{pkgname} %{apiversion}

Name:		openshadinglanguage%{libmajor}
Version:	1.10.13
Release:	%mkrel 5
Summary:	A language for programmable shading in advanced renderers
Group:		Graphics/3D
License:	BSD-3-Clause
Url:		https://github.com/imageworks/OpenShadingLanguage
Source0:	https://github.com/imageworks/OpenShadingLanguage/archive/Release-%{fver}.tar.gz
# from git
Patch1:		0001-Change-all-calls-to-Strutil-format-to-Strutil-sprint.patch
Patch2:		0001-Revise-shader-install-path-and-stdosl.h-search-956.patch
Patch3:         0003-no-neon.patch
# for llvm11 
Patch10:	0010-fix-std-string.patch
Patch11:	0011-fix-createcall-llvm11.patch

BuildRequires:	bison
BuildRequires:	cmake
BuildRequires:	clang
BuildRequires:	clang-devel
BuildRequires:	flex
BuildRequires:	llvm-devel
BuildRequires:	libboost-devel
BuildRequires:	openimageio
BuildRequires:	pkgconfig(OpenImageIO)
BuildRequires:	pkgconfig(IlmBase)
BuildRequires:	pkgconfig(OpenEXR)
BuildRequires:	pkgconfig(pugixml)

%description
Open Shading Language (OSL) is a small but rich language for
programmable shading in advanced renderers and other applications,
ideal for describing materials, lights, displacement, and pattern
generation.

%package -n %{libname}
Summary:	A language for programmable shading in advanced renderers
Group:		System/Libraries
Provides:	openshadinglanguage = %{version}-%{release}
Provides:	%{pkgname} = %{version}-%{release}
Provides:	lib%{pkgname} = %{version}-%{release}
Provides:	lib%{name} = %{version}-%{release}

%description -n %{libname}
Open Shading Language (OSL) is a small but rich language for
programmable shading in advanced renderers and other applications,
ideal for describing materials, lights, displacement, and pattern
generation.

This package contains the shared library of OpenShadingLanguage.

%package -n %{develname}
Summary:	Development files for the OpenShadingLanguage library
Group:		Development/C
Requires:	%{libname} = %{version}-%{release}
Provides:	%{pkgname}-devel = %{version}-%{release}
Provides:	lib%{pkgname}-devel = %{version}-%{release}
Provides:	lib%{name}-devel = %{version}-%{release}

%description -n %{develname}
Development files for the OpenShadingLanguage library.

Install this package if you want to compile applications using the
OpenShadingLanguage library.

%prep
%setup -q -n OpenShadingLanguage-Release-%{fver}
%autopatch -p1

%build
# TODO: rebuild without -DSTOP_ON_WARNING:BOOL=OFF
%cmake	\
	-DUSE_CPP=14 \
	-DUSE_fPIC:BOOL=ON \
	-DENABLERTTI:BOOL=ON \
	-DUSE_BOOST_WAVE:BOOL=ON \
	-DOSL_SHADER_INSTALL_DIR:PATH=%{_datadir}/%{name} \
	-DSTOP_ON_WARNING:BOOL=OFF \
%ifarch %{arm}
        -DOSL_OIIO_NO_NEON=ON
%endif	
# avoid build break in simmd which includes NEON armv8 instruction

%cmake_build

%install
%cmake_install

%files
%doc CHANGES.md CONTRIBUTING.md README.md
%license LICENSE
%{_bindir}/*
%{_datadir}/doc/OSL/*
%{_datadir}/%{name}

%files -n %{libname}
%{_libdir}/*.%{libmajor}{,.*}

%files -n %{develname}
%{_includedir}/*
%{_libdir}/*.so


%changelog
* Thu Dec 31 2020 wally <wally> 1.10.13-5.mga8
+ Revision: 1666797
- rebuild for boost 1.75.0

* Sun Dec 20 2020 wally <wally> 1.10.13-4.mga8
+ Revision: 1662039
- rebuild for boost 1.74.0

* Sat Dec 05 2020 ghibo <ghibo> 1.10.13-3.mga8
+ Revision: 1652992
- Add 2nd patch for building under llvm11
- Reorder patch numbering, closing holes.
- Add patch to fix building error about std::string.
+ tv <tv>
- rebuild for llvm/clang 11.0

* Sat Nov 07 2020 joequant <joequant> 1.10.13-1.mga8
+ Revision: 1643286
- update to latest point release 1.10.13

* Sat Nov 07 2020 joequant <joequant> 1.10.9-8.mga8
+ Revision: 1643249
- bump version
- disable simd neon only for arm32

* Sat Nov 07 2020 joequant <joequant> 1.10.9-7.mga8
+ Revision: 1643239
- disable unknown simd call for arm

* Fri Nov 06 2020 joequant <joequant> 1.10.9-6.mga8
+ Revision: 1643096
- bump up release for rebuild
- revert update to 1.11
- fix sources
- update to 1.11.8.0 and sync with fedora build
  Version 1.10 was not building because of obscure compile errors,
  and updating versions and porting patches did not work.

* Thu Nov 05 2020 joequant <joequant> 1.10.9-5.mga8
+ Revision: 1642845
- update build
+ daviddavid <daviddavid>
- rebuild for new openimageio 2.2.8.0

* Sat Sep 12 2020 daviddavid <daviddavid> 1.10.9-4.mga8
+ Revision: 1625303
- rebuild for new openexr/ilmbase 2.5.3

* Sun May 03 2020 wally <wally> 1.10.9-3.mga8
+ Revision: 1578093
- rebuild for boost 1.73.0

* Fri Apr 03 2020 daviddavid <daviddavid> 1.10.9-2.mga8
+ Revision: 1564141
- rebuild for new openimageio 2.1.13.0

* Thu Mar 26 2020 tv <tv> 1.10.9-1.mga8
+ Revision: 1560530
- new release
- rebuild for llvm-10.0.0

* Thu Feb 20 2020 umeabot <umeabot> 1.10.8-2.mga8
+ Revision: 1545098
- Mageia 8 Mass Rebuild

* Mon Jan 27 2020 daviddavid <daviddavid> 1.10.8-1.mga8
+ Revision: 1483769
- new version: 1.10.8
+ wally <wally>
- rebuild for boost 1.72.0
- build with new cmake macros

* Thu Oct 17 2019 daviddavid <daviddavid> 1.10.7-1.mga8
+ Revision: 1454221
- new version: 1.10.7 (LLVM 9 / clang 9 compatibility)
+ tv <tv>
- rebuild for llvm-9.0

* Mon Jul 15 2019 daviddavid <daviddavid> 1.10.5-2.mga8
+ Revision: 1421596
- rebuild for new openimageio 2.0.9

* Fri May 17 2019 ghibo <ghibo> 1.10.5-1.mga7
+ Revision: 1398164
- Update to release 1.10.5

* Fri Apr 26 2019 ghibo <ghibo> 1.10.4-3.mga7
+ Revision: 1395526
- Fix license

* Fri Apr 26 2019 ghibo <ghibo> 1.10.4-2.mga7
+ Revision: 1395482
- Added patches to fix lookup path for stdosl.h
- Fix URL

* Wed Apr 24 2019 ghibo <ghibo> 1.10.4-1.mga7
+ Revision: 1395059
- imported package openshadinglanguage1.10


* Tue Apr 23 2019 ghibo <ghibo> 1.10.4-1.mga7
- Initial release.
